@@ -3,8 +3,8 @@
 import mysql.connector
 
 from ..crud_operation_db import view_db_data, create_db_data, update_db_data, delete_db_data
-from FakeDB import My_DB
-from myfakedata import Value1, Value2, Value3, Value4, Value6
+from .FakeDB import My_DB
+from .myfakedata import Value1, Value2, Value3, Value4, Value6
 
 EMPTY_LIST = []
 
